@@ -1,5 +1,4 @@
-find_positions <-
-function (nams1, nams2) {
+find_positions <- function (nams1, nams2) {
     nams1 <- gsub("^", "\\^", nams1, fixed = TRUE)
     vals <- c(glob2rx(nams1), glob2rx(paste0(nams1, ":*")), glob2rx(paste0("*:", nams1)))
     out <- sort(unique(unlist(lapply(vals, grep, x = nams2))))
