@@ -772,7 +772,7 @@ mvJointModelBayes <- function (mvglmerObject, survObject, timeVar,
                     RE_inds = RE_inds,
                     RE_inds2 = RE_inds2,
                     transFuns = trans_Funs,
-                    mvglmer_components = components,
+                    mvglmer_components = c(components, list(data = dataL)),
                     coxph_components = list(data = dataS, Terms = Terms, Time = Time, 
                                             event = event, TermsU = TermsU,
                                             TermsFormulas_fixed = TermsFormulas_fixed,
