@@ -458,14 +458,17 @@ print.survfit.mvJMbayes <- function (x, ...) {
 ##########################################################################################
 
 plot.survfit.mvJMbayes <- function (x, split = c(1, 1), which_subjects = NULL, which_outcomes = NULL,
-                                    surv_in_all = TRUE, include.y = TRUE, fun = NULL, 
+                                    surv_in_all = TRUE, include.y = TRUE, fun = NULL,
+                                    abline = NULL,
                                     main = NULL, xlab = "Time", ylab = NULL, 
                                     zlab = "Event-Free Probability",
                                     include_CI = TRUE, fill_area_CI = TRUE, 
                                     col_points = "black", pch_points = 1,
                                     col_lines = "red", col_lines_CI = "black", 
                                     col_fill_CI = "lightgrey",
-                                    lwd_lines = 2, lty_lines_CI = 2, ...) {
+                                    lwd_lines = 2, lty_lines_CI = 2, 
+                                    cex_xlab = 1, cex_ylab = 1, cex_zlab = 1, cex_main = 1,
+                                    cex_axis = 1, ...) {
     families <- x$families
     ylim <- NULL
     respVars <- x$respVars
@@ -495,9 +498,11 @@ plot.survfit.mvJMbayes <- function (x, split = c(1, 1), which_subjects = NULL, w
         }
         lines(times, surv, lwd = lwd_lines, col = col_lines)
         abline(v = x$last.time[[i]], lty = 2)
-        if (xaxis) axis(1)
-        axis(4)
-        mtext(zlab, side = 4, line = 1.8, outer = outer)
+        if (!is.null(abline))
+            abline(v = abline$v, lty = abline$lty, lwd = abline$lwd, col = abline$col)
+        if (xaxis) axis(1, cex.axis = cex_axis)
+        axis(4, cex.axis = cex_axis)
+        mtext(zlab, side = 4, line = 1.8, outer = outer, cex = cex_zlab)
     }
     if (is.null(ylab))
         ylab <- respVars
@@ -539,19 +544,19 @@ plot.survfit.mvJMbayes <- function (x, split = c(1, 1), which_subjects = NULL, w
                      type = "n")
                 box()
                 points(obs_times, y, col = col_points, pch = pch_points)
-                if (fact_y) axis(2, at = 0:1, labels = lvy) else axis(2)
-                if (add_xaxis <- par()$mfcol[1L] == j) axis(1)
+                if (fact_y) axis(2, at = 0:1, labels = lvy, cex.axis = cex_axis) else axis(2, cex.axis = cex_axis)
+                if (add_xaxis <- par()$mfcol[1L] == j) axis(1, cex.axis = cex_axis)
                 lines(fitted_times, fitted_y, lwd = lwd_lines, col = col_lines)
                 abline(v = x$last.time[[i]], lty = 2)
-                mtext(ylab[j], side = 2, line = 1.8)
+                mtext(ylab[j], side = 2, line = 1.8, cex = cex_ylab)
                 ylim <- NULL
                 if (surv_in_all) {
                     par(new = TRUE)
                     add_surv(add_xaxis)
                 }
                 if (added_xlab <- all(par()$mfcol == c(1, 1))) {
-                    mtext(xlab, side = 1, line = 1.5, outer = TRUE)
-                    mtext(main[i], side = 3, line = 0.8, outer = TRUE)
+                    mtext(xlab, side = 1, line = 1.5, outer = TRUE, cex = cex_xlab)
+                    mtext(main[i], side = 3, line = 0.8, outer = TRUE, cex = cex_main)
                 }
             }
         }
@@ -559,8 +564,8 @@ plot.survfit.mvJMbayes <- function (x, split = c(1, 1), which_subjects = NULL, w
             add_surv(outer = FALSE)
         }
         if (!include.y || !added_xlab) {
-            mtext(xlab, side = 1,line = 1.5, outer = TRUE)
-            mtext(main[i], side = 3, line = 0.8, outer = TRUE)
+            mtext(xlab, side = 1,line = 1.5, outer = TRUE, cex = cex_xlab)
+            mtext(main[i], side = 3, line = 0.8, outer = TRUE, cex = cex_main)
         }
         par(opar)
     }
